package javax.swing.text.html;

import java.awt.Rectangle;
import java.awt.Shape;
import java.awt.Graphics;
import java.awt.Container;
import javax.swing.text.JTextComponent;
import javax.swing.SizeRequirements;
import javax.swing.text.View;
import javax.swing.text.Element;
import javax.swing.text.AttributeSet;

public class ParagraphView extends javax.swing.text.ParagraphView
{
    private AttributeSet attr;
    private StyleSheet.BoxPainter painter;
    private CSS.LengthValue cssWidth;
    private CSS.LengthValue cssHeight;
    
    public ParagraphView(Element elem) {
        super(elem);
    }
    
    @Override
    public void setParent(View parent) {
        super.setParent(parent);
        if (parent != null) {
            this.setPropertiesFromAttributes();
        }
    }
    
    @Override
    public AttributeSet getAttributes() {
        if (this.attr == null) {
            this.attr = this.getStyleSheet().getViewAttributes(this);
        }
        return this.attr;
    }
    
    @Override
    protected void setPropertiesFromAttributes() {
        StyleSheet styleSheet = this.getStyleSheet();
        this.attr = styleSheet.getViewAttributes(this);
        this.painter = styleSheet.getBoxPainter(this.attr);
        if (this.attr != null) {
            super.setPropertiesFromAttributes();
            this.setInsets((short)(int)this.painter.getInset(1, this), (short)(int)this.painter.getInset(2, this), (short)(int)this.painter.getInset(3, this), (short)(int)this.painter.getInset(4, this));
            Object attribute = this.attr.getAttribute(CSS.Attribute.TEXT_ALIGN);
            if (attribute != null) {
                String string = attribute.toString();
                if (string.equals("left")) {
                    this.setJustification(0);
                }
                else if (string.equals("center")) {
                    this.setJustification(1);
                }
                else if (string.equals("right")) {
                    this.setJustification(2);
                }
                else if (string.equals("justify")) {
                    this.setJustification(3);
                }
            }
            this.cssWidth = (CSS.LengthValue)this.attr.getAttribute(CSS.Attribute.WIDTH);
            this.cssHeight = (CSS.LengthValue)this.attr.getAttribute(CSS.Attribute.HEIGHT);
        }
    }
    
    protected StyleSheet getStyleSheet() {
        return ((HTMLDocument)this.getDocument()).getStyleSheet();
    }
    
    @Override
    protected SizeRequirements calculateMinorAxisRequirements(int axis, SizeRequirements calculateMinorAxisRequirements) {
        calculateMinorAxisRequirements = super.calculateMinorAxisRequirements(axis, calculateMinorAxisRequirements);
        if (BlockView.spanSetFromAttributes(axis, calculateMinorAxisRequirements, this.cssWidth, this.cssHeight)) {
            int n = (axis == 0) ? (this.getLeftInset() + this.getRightInset()) : (this.getTopInset() + this.getBottomInset());
            SizeRequirements sizeRequirements = calculateMinorAxisRequirements;
            sizeRequirements.minimum -= n;
            SizeRequirements sizeRequirements2 = calculateMinorAxisRequirements;
            sizeRequirements2.preferred -= n;
            SizeRequirements sizeRequirements3 = calculateMinorAxisRequirements;
            sizeRequirements3.maximum -= n;
            return calculateMinorAxisRequirements;
        }
        return calculateMinorAxisRequirements;
    }
    
    @Override
    public boolean isVisible() {
        int index = this.getLayoutViewCount() - 1;
        int i = 0;
        while (i < index) {
            if (this.getLayoutView(i).isVisible()) {
                return true;
            }
            ++i;
        }
        if (index > 0) {
            View layoutView = this.getLayoutView(index);
            if (layoutView.getEndOffset() - layoutView.getStartOffset() == 1) {
                return false;
            }
        }
        if (this.getStartOffset() == this.getDocument().getLength()) {
            boolean editable = false;
            Container container = this.getContainer();
            if ((container instanceof JTextComponent)) {
                editable = ((JTextComponent)container).isEditable();
            }
            if (editable == 0) {
                return false;
            }
        }
        return true;
    }
    
    @Override
    public void paint(Graphics g, Shape a) {
        if (a == null) {
            return;
        }
        Rectangle bounds;
        if ((a instanceof Rectangle)) {
            bounds = (Rectangle)a;
        }
        else {
            bounds = a.getBounds();
        }
        this.painter.paint(g, (float)bounds.x, (float)bounds.y, (float)bounds.width, (float)bounds.height, this);
        super.paint(g, a);
        return;
    }
    
    @Override
    public float getPreferredSpan(int axis) {
        if (!this.isVisible()) {
            return 0.0f;
        }
        return super.getPreferredSpan(axis);
    }
    
    @Override
    public float getMinimumSpan(int axis) {
        if (!this.isVisible()) {
            return 0.0f;
        }
        return super.getMinimumSpan(axis);
    }
    
    @Override
    public float getMaximumSpan(int axis) {
        if (!this.isVisible()) {
            return 0.0f;
        }
        return super.getMaximumSpan(axis);
    }
}
